==> anwiba-spatial-data-gpsd-1.0.68-sources.jar: net/anwiba/spatial/gps/gpsd/response/Poll.java <==
//// Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonProperty;

public class Poll
    extends Response
{

    private final String _class = "POLL";
    private String time = null;
    private int active = 0;
    private Tpv[] tpv = null;
    private Gst[] gst = null;
    private Sky[] sky = null;

    @JsonProperty("class")
    public void setClass(final String _class) {
    }

    @JsonProperty("class")
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("time")
    public void setTime(final String time) {
        this.time = time;
    }

    @JsonProperty("time")
    public String getTime() {
        return this.time;
    }

    @JsonProperty("active")
    public void setActive(final int active) {
        this.active = active;
    }

    @JsonProperty("active")
    public int getActive() {
        return this.active;
    }

    @JsonProperty("tpv")
    public void setTpv(final Tpv[] tpv) {
        this.tpv = tpv;
    }

    @JsonProperty("tpv")
    public Tpv[] getTpv() {
        return this.tpv;
    }

    @JsonProperty("gst")
    public void setGst(final Gst[] gst) {
        this.gst = gst;
    }

    @JsonProperty("gst")
    public Gst[] getGst() {
        return this.gst;
    }

    @JsonProperty("sky")
    public void setSky(final Sky[] sky) {
        this.sky = sky;
    }

    @JsonProperty("sky")
    public Sky[] getSky() {
        return this.sky;
    }

}

==> anwiba-spatial-data-gpsd-1.0.154-sources.jar: net/anwiba/spatial/gps/gpsd/response/Poll.java <==
//// Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Poll
    extends Response
{

    private final String _class = "POLL";
    private String time = null;
    private int active = 0;
    private Tpv[] tpv = null;
    private Gst[] gst = null;
    private Sky[] sky = null;

    @JsonIgnore
    public void setClass(final String _class) {
    }

    @JsonIgnore
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("time")
    public void setTime(final String time) {
        this.time = time;
    }

    @JsonProperty("time")
    public String getTime() {
        return this.time;
    }

    @JsonProperty("active")
    public void setActive(final int active) {
        this.active = active;
    }

    @JsonProperty("active")
    public int getActive() {
        return this.active;
    }

    @JsonProperty("tpv")
    public void setTpv(final Tpv[] tpv) {
        this.tpv = tpv;
    }

    @JsonProperty("tpv")
    public Tpv[] getTpv() {
        return this.tpv;
    }

    @JsonProperty("gst")
    public void setGst(final Gst[] gst) {
        this.gst = gst;
    }

    @JsonProperty("gst")
    public Gst[] getGst() {
        return this.gst;
    }

    @JsonProperty("sky")
    public void setSky(final Sky[] sky) {
        this.sky = sky;
    }

    @JsonProperty("sky")
    public Sky[] getSky() {
        return this.sky;
    }

}
